@@ -87,9 +87,6 @@ sub _insert_class {
 	    if exists $data->{$_}
     }
 
-    $opt{param}{private} = (delete $data->{private}? 'true': 'false')
-	if exists $data->{private};
-
     $class->SUPER::_insert_class($data, %opt);
 }
 
@@ -103,7 +100,7 @@ sub _insert_class {
         name => string,
         password =. string,
         seats => int,
-        private => 0|1,
+        privateMeeting => 0|1,
         timeZone => string
        });
 
@@ -122,12 +119,6 @@ sub update {
 	    if exists $data->{$_}
     }
 
-    $opt{param}{private} = (delete $data->{private}? 'true': 'false')
-	if exists $data->{private};
-
-    warn YAML::Dump({meeting_opts => \%opt})
-	if (Elive->debug);
-
     $self->SUPER::update($data, %opt);
 }
 
@@ -287,42 +278,33 @@ sub add_preload {
     $self->_check_for_errors($som);
 }
 
-=head2 list_preloads
+=head2 check_preload
 
-my $preloads = Elive::Entity::Preload->list_meeting_preloads($meeting_id);
+my $ok = Elive::Entity::Meeting->check_preload($preload);
 
-Implements the listMeetingPreloads method
+Checks that the preload is associated with ths meeting.
 
 =cut
 
-sub list_preloads {
+sub check_preload {
     my $self = shift;
+    my $preload_id = shift;
     my %opt = @_;
 
-    my $meeting_id = $opt{meeting_id} || $self->meetingId;
+    $preload_id = $preload_id->preloadId
+	if ref($preload_id);
 
-    return $self->fetch({meetingId => $meeting_id},
-			 adapter => 'listMeetingPreloads',
-			 %opt
-	);
-}
+    my $adapter = $self->check_adapter('checkMeetingPreload');
 
-=head2 check_preloads
+    my $som =  $self->connection->call($adapter,
+				       preloadId => $preload_id,
+				       meetingId => $self->meetingId);
 
-my $preloads = Elive::Entity::Preload->check_meeting_preloads($meeting_id);
+    $self->_check_for_errors($som);
 
-Implements the checkMeetingPreloads method
+    my $results = $self->_unpack_as_list($som->result);
 
-=cut
-
-sub check_preloads {
-    my $self = shift;
-    my %opt = @_;
-
-    my $meeting_id = $opt{meeting_id} || $self->meetingId;
-
-    return $self->fetch({meetingId => $meeting_id},
-			 adapter => 'checkMeetingPreloads');
+    return @$results && $results->[0] eq 'true';
 }
 
 sub _freeze {
@@ -394,11 +376,6 @@ Elive::Entity::Preload
 Elive::Entity::MeetingParameters 
 Elive::Entity::ServerParameters
 
-=head1 BUGS & LIMITATIONS
-
-Seems that privateMeeting gets ignored on update for Elluminate Live 9 & 9.1.
-If you try to set it the readback check may fail.
-
 =cut
 
 1;
